@@ -81,7 +81,7 @@
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
 #define HAVE_SYS_SYSCALL_H 1
-#define HAVE_SYS_TIMEB_H 1
+/* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TYPES_H 1
@@ -198,7 +198,7 @@
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_KEY_DELETE 1
-#define HAVE_PTHREAD_KILL 1
+/* #undef HAVE_PTHREAD_KILL */
 #define HAVE_PTHREAD_RWLOCK_RDLOCK 1
 #define HAVE_PTHREAD_SIGMASK 1
 /* #undef HAVE_PTHREAD_YIELD_NP */
@@ -444,7 +444,11 @@
 /*
   MySQL features
 */
-#define ENABLED_LOCAL_INFILE 1
+#define LOCAL_INFILE_MODE_OFF  0
+#define LOCAL_INFILE_MODE_ON   1
+#define LOCAL_INFILE_MODE_AUTO 2
+#define ENABLED_LOCAL_INFILE LOCAL_INFILE_MODE_ON
+
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
 /* #undef USE_SYMDIR */
@@ -534,16 +538,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 3
-#define MYSQL_VERSION_PATCH 12
+#define MYSQL_VERSION_PATCH 15
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.3.12"
+#define PACKAGE_STRING "MySQL Server 10.3.15"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.3.12"
-#define VERSION "10.3.12"
+#define PACKAGE_VERSION "10.3.15"
+#define VERSION "10.3.15"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
